@@ -52,24 +52,24 @@
 #' @export
 numPed <- function(pedigree, check = TRUE){
  if(!is.numPed(pedigree) && check){      
-  if(any(pedigree[, 2] == 0, na.rm = TRUE)){
-    pedigree[which(pedigree[, 2] == 0), 2] <- NA
+  if(any(d0 <- pedigree[, 2] == 0, na.rm = TRUE)){
+    pedigree[which(d0), 2] <- NA
     warning("Zero in the dam column interpreted as a missing parent")
   }
-  if(any(pedigree[, 3] == 0, na.rm = TRUE)){
-    pedigree[which(pedigree[, 3] == 0), 3] <- NA
+  if(any(s0 <- pedigree[, 3] == 0, na.rm = TRUE)){
+    pedigree[which(s0), 3] <- NA
     warning("Zero in the sire column interpreted as a missing parent")
   }
-  if(any(pedigree[, 2] == -998, na.rm = TRUE)){
-    pedigree[which(pedigree[, 2] == -998), 2] <- NA
+  if(any(d998 <- pedigree[, 2] == -998, na.rm = TRUE)){
+    pedigree[which(d998), 2] <- NA
     if(!is.numPed(pedigree)) warning("-998 in the dam column interpreted as a missing parent")
   }
-  if(any(pedigree[, 3] == -998, na.rm = TRUE)){
-    pedigree[which(pedigree[, 3] == -998), 3] <- NA
+  if(any(s998 <- pedigree[, 3] == -998, na.rm = TRUE)){
+    pedigree[which(s998), 3] <- NA
     if(!is.numPed(pedigree)) warning("-998 in the sire column interpreted as a missing parent")
   }
-  if(any(pedigree[,2] == "*", na.rm = TRUE)) pedigree[which(pedigree[, 2] == "*"), 2] <- NA
-  if(any(pedigree[,3] == "*", na.rm = TRUE)) pedigree[which(pedigree[, 3] == "*"), 3] <- NA
+  if(any(dast <- pedigree[, 2] == "*", na.rm = TRUE)) pedigree[which(dast), 2] <- NA
+  if(any(sast <- pedigree[, 3] == "*", na.rm = TRUE)) pedigree[which(sast), 3] <- NA
 
   if(all(is.na(pedigree[, 2])) & all(is.na(pedigree[, 3]))){
      stop("All dams and sires are missing")
